==> crowdcent_challenge-0.1.1.tar.gz: crowdcent_challenge-0.1.1/docs/index.md <==
# CrowdCent Challenge
Welcome to the documentation for the `crowdcent-challenge`. Please check back soon for detailed information about the challenge rules and format.

Anyone can submit to this documentation or improve the python client and CLI for the `crowdcent-challenge` API. Please see the [contributing guidelines](contributing.md) for more information.

Explore the rules, understand the scoring, get started with the python client, or dive into the API reference.

<div class="grid cards" markdown>

-   :material-scale-balance:{ .lg .middle } Challenge Rules

    ---

    Understand the official rules and guidelines for participating in the CrowdCent Challenge.

    [:octicons-arrow-right-24: Read the Rules](rules.md)

-   :material-scoreboard:{ .lg .middle } Scoring System

    ---

    Learn how submissions are evaluated and how the leaderboard rankings work.

    [:octicons-arrow-right-24: View Scoring Details](scoring.md)

-   :material-language-python:{ .lg .middle } Python Client

    ---

    Install the client library and make your first submission quickly.

    [:octicons-arrow-right-24: Quick Start Guide](quickstart.md)

-   :material-api:{ .lg .middle } API Reference

    ---

    Detailed reference for the Python client and the command-line interface.

    [:octicons-arrow-right-24: Explore the API](python_reference.md)

</div>
## Have Questions?
If you need immediate assistance, please email us at info@crowdcent.com or join our [Discord server](https://discord.gg/v6ZSGuTbQS).

==> crowdcent_challenge-0.1.3.tar.gz: crowdcent_challenge-0.1.3/docs/index.md <==
# CrowdCent Challenge Documentation
Welcome to the documentation for the `crowdcent-challenge`. Please check back soon for detailed information about the challenge rules and format.

Explore the rules, understand the scoring, get started with the python client, or dive into the API reference.

<div class="grid cards" markdown>

-   :material-scale-balance:{ .lg .middle } Challenge Rules

    ---

    Understand the official rules and guidelines for participating in the CrowdCent Challenge.

    [:octicons-arrow-right-24: Read the Rules](rules.md)

-   :material-scoreboard:{ .lg .middle } Scoring System

    ---

    Learn how submissions are evaluated and how the leaderboard rankings work.

    [:octicons-arrow-right-24: View Scoring Details](scoring.md)

-   :material-language-python:{ .lg .middle } Python Client

    ---

    Install the client library and make your first submission quickly.

    [:octicons-arrow-right-24: Quick Start Guide](install_quickstart.md)

-   :material-api:{ .lg .middle } API Reference

    ---

    Detailed reference for the Python client and the command-line interface.

    [:octicons-arrow-right-24: Explore the API](python_reference.md)

</div>
## Have Questions?
If you need immediate assistance, please email us at info@crowdcent.com or join our [Discord server](https://discord.gg/v6ZSGuTbQS).

## Want to Contribute?
Anyone can submit to this documentation or improve the python client and CLI for the `crowdcent-challenge` API. Please see the [contributing guidelines](contributing.md) for more information. If you'd like to join the conversation, please join our [Discord server](https://discord.gg/v6ZSGuTbQS).
